<?php
/**
 * Smarty plugin
 * @package Smarty
 * @subpackage plugins
 */


function smarty_function_allegro_disp_sff( $params, &$smarty ){
    GLOBAL $allegro_sff, $allegro_cats, $allegro_states, $allegro_countries;

    $sff = array();
    if( isset($params['sff_id']) ){
        $sff_id = $params['sff_id'];

        if( empty($allegro_sff[$sff_id]) ){
            return null;
        }

        $sff = $allegro_sff[$sff_id];
    }else if( isset($params['sff']) ){
        $sff = $params['sff'];
    }else{
        return;
    }

    $field_id = $sff['id'];

    $val = isset($params['value']) ? $params['value'] : '';
    $title = echtmlspecialchars(trim($sff['title']));
    $value = '';

    switch( $sff ['type'] ){
        case 1: //if type of field is string
        case 2: //if type of field is integer
        case 3: //if type of field is float
            $value = html_escape($val);
        break;

        case 4: //if type of field is combobox
        case 5: //if type of field is radiobutton
            $options = allegro_sff_options( $field_id );
            $value = ( isset($options[$val]) ) ? $options[$val] : '-';
        break;

        case 6: //if type of field is checkbox
            $options = allegro_sff_options( $field_id );

            if( !is_array($val) ){
                $val = intval($val);

                $tmp = array();
                for( $i = 0, $lp = count($options); $i < $lp; $i++ ){
                    $tmp[$i] = ($val & pow(2, $i)) ? 1  : 0;
                }
                $val = $tmp;
            }

            $i = 0;
            foreach( $options as $k => $v ){
                if( isset($val[$i]) && ($val[$i] == 1) ){
                    $value .= echtmlspecialchars($v) . ', ';
                }
                $i++;
            }
        break;

        case 7: //if type of field is image (base64Binary)
            if( !empty($val) ){
                $value = '<img src="'.$val.'&amp;size=mini" title="'.$title.'" alt="'.$title.'">';
            }else{
                $value = 'Zdjecie nie zostao przesane.';
            }
        break;

        case 8: //if type of field is text (textarea)
            $value = html_escape($val);
        break;

        case 9: //if type of field is datetime - (second's number since 1.1.1970)
            $val = intval($val);
            if( $val > 0 ){
                $value = date('Y-m-d H:i:s', $val);
            }
        break;

        case 10: //if type of field is country-id
            $value = $allegro_countries[$val];
        break;

        case 11: //if type of field is state-id
            $value = $allegro_states[$val];
        break;

        case 12: //if type of field is category-id
            $value = smarty_function_allegro_cat_path($val);
        break;

        case 13:
            //* 13 - if type of field is boolean
            $value = ( $val == 1 ) ? 'Tak' : 'Nie';
        break;
    }


return '
      <tr>
    		<td valign="top" class="nowrap attribs-hsep">'. $title .':</td>
    		<td class="bold nowrap attribs-hsep">'. (empty($value) ? ' - ' : $value ) .'</td>
    	</tr>
';
    
}

?>
